@@ -20,16 +20,18 @@ def compile_create_materialized_view(element, compiler, **kw):
 
 
 class DropView(DDLElement):
-    def __init__(self, name, materialized=False):
+    def __init__(self, name, materialized=False, cascade=True):
         self.name = name
         self.materialized = materialized
+        self.cascade = cascade
 
 
 @compiler.compiles(DropView)
 def compile_drop_materialized_view(element, compiler, **kw):
-    return 'DROP {}VIEW IF EXISTS {} CASCADE'.format(
+    return 'DROP {}VIEW IF EXISTS {} {}'.format(
         'MATERIALIZED ' if element.materialized else '',
-        element.name
+        element.name,
+        'CASCADE' if element.cascade else ''
     )
 
 
@@ -37,14 +39,22 @@ def create_table_from_selectable(
     name,
     selectable,
     indexes=None,
-    metadata=None
+    metadata=None,
+    aliases=None
 ):
     if indexes is None:
         indexes = []
     if metadata is None:
         metadata = sa.MetaData()
+    if aliases is None:
+        aliases = {}
     args = [
-        sa.Column(c.name, c.type, primary_key=c.primary_key)
+        sa.Column(
+            c.name,
+            c.type,
+            key=aliases.get(c.name, c.name),
+            primary_key=c.primary_key
+        )
         for c in selectable.c
     ] + indexes
     table = sa.Table(name, metadata, *args)
@@ -60,7 +70,8 @@ def create_materialized_view(
     name,
     selectable,
     metadata,
-    indexes=None
+    indexes=None,
+    aliases=None
 ):
     """ Create a view on a given metadata
 
@@ -70,6 +81,9 @@ def create_materialized_view(
         An SQLAlchemy Metadata instance that stores the features of the
         database being described.
     :param indexes: An optional list of SQLAlchemy Index instances.
+    :param aliases:
+        An optional dictionary containing with keys as column names and values
+        as column aliases.
 
     Same as for ``create_view`` except that a ``CREATE MATERIALIZED VIEW``
     statement is emitted instead of a ``CREATE VIEW``.
@@ -79,7 +93,8 @@ def create_materialized_view(
         name=name,
         selectable=selectable,
         indexes=indexes,
-        metadata=None
+        metadata=None,
+        aliases=aliases
     )
 
     sa.event.listen(
@@ -104,7 +119,8 @@ def create_materialized_view(
 def create_view(
     name,
     selectable,
-    metadata
+    metadata,
+    cascade_on_drop=True
 ):
     """ Create a view on a given metadata
 
@@ -149,7 +165,11 @@ def create_view(
         for idx in table.indexes:
             idx.create(connection)
 
-    sa.event.listen(metadata, 'before_drop', DropView(name))
+    sa.event.listen(
+        metadata,
+        'before_drop',
+        DropView(name, cascade=cascade_on_drop)
+    )
     return table
 
 
